@@ -1,15 +1,18 @@
-use 5.10.1;
+use 5.10.0;
 use strict;
 use warnings;
 
 package Dist::Zilla::Plugin::Stenciller::HtmlExamples;
 
-our $VERSION = '0.0200'; # VERSION
 # ABSTRACT: Create Html example files from text files parsed with Stenciller
+our $AUTHORITY = 'cpan:CSSON'; # AUTHORITY
+our $VERSION = '0.0201';
 
 use Moose;
 with 'Dist::Zilla::Role::FileGatherer';
 use Stenciller;
+use Types::Standard qw/Bool Maybe Str/;
+use Types::Path::Tiny qw/AbsFile Dir Path/;
 use Types::Stenciller -types;
 use Path::Tiny;
 use Dist::Zilla::File::InMemory;
@@ -144,22 +147,21 @@ Dist::Zilla::Plugin::Stenciller::HtmlExamples - Create Html example files from t
 
 
 
-=begin HTML
+=begin html
 
-<p><img src="https://img.shields.io/badge/perl-5.14+-brightgreen.svg" alt="Requires Perl 5.14+" /> <a href="https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-Stenciller-HtmlExamples"><img src="https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-Stenciller-HtmlExamples.svg?branch=master" alt="Travis status" /></a> <img src="https://img.shields.io/badge/coverage-98.3%-yellow.svg" alt="coverage 98.3%" /></p>
+<p>
+<img src="https://img.shields.io/badge/perl-5.10+-blue.svg" alt="Requires Perl 5.10+" />
+<a href="https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-Stenciller-HtmlExamples"><img src="https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-Stenciller-HtmlExamples.svg?branch=master" alt="Travis status" /></a>
+<a href="http://cpants.cpanauthors.org/dist/Dist-Zilla-Plugin-Stenciller-HtmlExamples-0.0201"><img src="https://badgedepot.code301.com/badge/kwalitee/Dist-Zilla-Plugin-Stenciller-HtmlExamples/0.0201" alt="Distribution kwalitee" /></a>
+<a href="http://matrix.cpantesters.org/?dist=Dist-Zilla-Plugin-Stenciller-HtmlExamples%200.0201"><img src="https://badgedepot.code301.com/badge/cpantesters/Dist-Zilla-Plugin-Stenciller-HtmlExamples/0.0201" alt="CPAN Testers result" /></a>
+<img src="https://img.shields.io/badge/coverage-98.5%-yellow.svg" alt="coverage 98.5%" />
+</p>
 
-=end HTML
-
-
-=begin markdown
-
-![Requires Perl 5.14+](https://img.shields.io/badge/perl-5.14+-brightgreen.svg) [![Travis status](https://api.travis-ci.org/Csson/p5-Dist-Zilla-Plugin-Stenciller-HtmlExamples.svg?branch=master)](https://travis-ci.org/Csson/p5-Dist-Zilla-Plugin-Stenciller-HtmlExamples) ![coverage 98.3%](https://img.shields.io/badge/coverage-98.3%-yellow.svg)
-
-=end markdown
+=end html
 
 =head1 VERSION
 
-Version 0.0200, released 2016-01-27.
+Version 0.0201, released 2016-03-23.
 
 
 
